import { ChangeDetectorRef, ElementRef, EventEmitter, SimpleChanges } from '@angular/core';
import { DrawerService } from '../../service/drawer.service';
import { StateListener } from '../../state-listener.component';
export declare type DrawerNavItem = {
    statusColor?: string;
    title: string;
    subtitle?: string;
    chevron?: boolean;
    divider?: boolean;
    items?: Array<Omit<DrawerNavItem, 'icon'>>;
    onSelect?: any;
    icon?: string;
    hasChildren?: boolean;
    ripple?: boolean;
    expanded?: boolean;
    hidePadding?: boolean;
    hidden?: boolean;
};
export declare type ActiveItemBackgroundShape = 'round' | 'square';
/**
 * [DrawerNavItem Component](https://brightlayer-ui-components.github.io/angular/?path=/info/components-drawer--readme)
 *
 * The `<blui-drawer-nav-item>` is a wrapper to the `<blui-info-list-item>` that is meant to be used within a `<blui-nav-group>`.
 */
export declare class DrawerNavItemComponent extends StateListener implements Omit<DrawerNavItem, 'items'> {
    /** Sets the active item background shape
     *
     * `square` - Background shape takes the entire height of width of the NavItem.
     * `round` - Background shape has a rounded corner towards the end of the NavItem.
     *
     * @default square
     * */
    activeItemBackgroundShape: ActiveItemBackgroundShape;
    /** Sets whether to show a chevron icon on the left side of a `NavItem`
     *
     * @default false
     * */
    chevron: boolean;
    /** Whether to show a dividing line below each NavItem
     *
     * @default false
     * */
    divider: boolean;
    /** Sets whether to show nested nav items
     *
     * @default false
     * */
    expanded: boolean;
    /** Sets whether to show/hide padding whenever a NavItem does not have an icon */
    hidePadding: boolean;
    /** Sets whether to hide the nav item
     *
     * @default false
     * */
    hidden: boolean;
    /** Sets whether to show/hide Angular ripple animation effect onClick
     *
     * @default true
     * */
    ripple: boolean;
    /** Sets whether an item is selected.  A selected item will have the `activeBackgroundShape` applied to it and appear different from all other NavItems.*/
    selected: boolean;
    /** Left border color */
    statusColor: string;
    /** Text to display as a subtitle */
    subtitle: string;
    /** Text to display as a title */
    title: string;
    /** Event triggered on nav item select */
    select: EventEmitter<string>;
    nestedNavItems: any;
    expandIconEl: ElementRef;
    iconEl: ElementRef;
    collapseIconEl: ElementRef;
    navItemEl: ElementRef;
    isEmpty: (el: ElementRef) => boolean;
    isNestedItem: boolean;
    hasChildren: boolean;
    depth: number;
    id: number;
    constructor(drawerService: DrawerService, changeDetectorRef: ChangeDetectorRef);
    ngAfterContentInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    isRail(): boolean;
    isRailCondensed(): boolean;
    showTooltipOnRailHover(): boolean;
    /** Whenever the selected item in the drawer state changes, we need to check to see we should apply a hierarchical highlight. */
    manageActiveItemTreeHighlight(): void;
    listenForDrawerChanges(): void;
    incrementDepth(parentDepth: number): void;
    /** Sets default state values for non-nested nav items. */
    setNavItemDefaults(): void;
    /** Sets default state values for nested nav items. */
    setNestedDrawerDefaults(): void;
    selectItem(): void;
    toggleNestedNavItems(): void;
}
